diff --git a/InnerDetector/InDetDetDescr/InDetRegionSelector/InDetRegionSelector/SiRegionSelectorTable.h b/InnerDetector/InDetDetDescr/InDetRegionSelector/InDetRegionSelector/SiRegionSelectorTable.h
index 8009d741ff0195793d4fd7d571cb9e5402db27fb..a56457bcc235f3eb4592b741ae951a6f6eaf76df 100755
--- a/InnerDetector/InDetDetDescr/InDetRegionSelector/InDetRegionSelector/SiRegionSelectorTable.h
+++ b/InnerDetector/InDetDetDescr/InDetRegionSelector/InDetRegionSelector/SiRegionSelectorTable.h
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
  
 #ifndef InDetRegionSelector_SiRegionSelectorTable_h
@@ -48,7 +48,7 @@ private:
 
   // cablings
   ServiceHandle<IPixelCablingSvc> m_pixIdMapping;
-  ToolHandle<ISCT_CablingTool>  m_sctCablingToolCB; // This class accesses SCT cabling during initialization.
+  ToolHandle<ISCT_CablingTool>  m_sctCablingToolInc; // This class accesses SCT cabling during initialization.
 
 };
 
diff --git a/InnerDetector/InDetDetDescr/InDetRegionSelector/src/SiRegionSelectorTable.cxx b/InnerDetector/InDetDetDescr/InDetRegionSelector/src/SiRegionSelectorTable.cxx
index 6df46e4b607c33dc09d6ede80d621d2c7a132021..c465d725fc5e583abb19a687cbaa884e89edcf97 100755
--- a/InnerDetector/InDetDetDescr/InDetRegionSelector/src/SiRegionSelectorTable.cxx
+++ b/InnerDetector/InDetDetDescr/InDetRegionSelector/src/SiRegionSelectorTable.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
   
 #include "InDetRegionSelector/SiRegionSelectorTable.h"
@@ -40,7 +40,7 @@ SiRegionSelectorTable::SiRegionSelectorTable(const std::string& type,
      m_printTable(false),
      m_noDBM(true),
      m_pixIdMapping("PixelCablingSvc", name),
-     m_sctCablingToolCB("SCT_CablingToolCB")
+     m_sctCablingToolInc("SCT_CablingToolInc")
 {
   declareInterface<IRegionIDLUT_Creator>(this);
   declareProperty("ManagerName", m_managerName);
@@ -126,8 +126,8 @@ SiRegionSelectorTable::createTable()
       return StatusCode::FAILURE;
     }
   } else { // SCT
-    if (m_sctCablingToolCB.retrieve().isFailure()) {
-      msg(MSG::ERROR) << "Can't get the SCT_CablingToolCB." << endmsg;
+    if (m_sctCablingToolInc.retrieve().isFailure()) {
+      msg(MSG::ERROR) << "Can't get the SCT_CablingToolInc." << endmsg;
       return StatusCode::FAILURE;
     }
   }
@@ -187,7 +187,7 @@ SiRegionSelectorTable::createTable()
 	if ( sctId!=0 ) {      
 	  barrelEC  = sctId->barrel_ec(element->identify());
 	  layerDisk = sctId->layer_disk(element->identify());
-	  robId=m_sctCablingToolCB->getRobIdFromOfflineId(element->identify());
+	  robId=m_sctCablingToolInc->getRobIdFromOfflineId(element->identify());
 	}
 	else { 
 	  msg(MSG::ERROR) << " could not get SCT_ID for " << element->getIdHelper() << endmsg;
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfig.py b/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfig.py
index 55bd8fd06fbf57911598f9cb157e951c5789c649..9eb0341eefee2c8951ae9785669e8d1b1c9a98a9 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfig.py
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfig.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2018 CERN for the benefit of the ATLAS collaboration
+# Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 
 # https://twiki.cern.ch/twiki/bin/viewauth/AtlasComputing/ConfiguredFactory
 
@@ -63,9 +63,9 @@ def getSCT_CablingCondAlgFromCoraCool(name="SCT_CablingCondAlgFromCoraCool", **k
     from SCT_Cabling.SCT_CablingConf import SCT_CablingCondAlgFromCoraCool
     return CfgMgr.SCT_CablingCondAlgFromCoraCool(name, **kwargs)
 
-def getSCT_CablingToolCB(name="SCT_CablingToolCB", **kwargs):
-    from SCT_Cabling.SCT_CablingConf import SCT_CablingToolCB
-    return CfgMgr.SCT_CablingToolCB(name, **kwargs)
+def getSCT_CablingToolInc(name="SCT_CablingToolInc", **kwargs):
+    from SCT_Cabling.SCT_CablingConf import SCT_CablingToolInc
+    return CfgMgr.SCT_CablingToolInc(name, **kwargs)
 
 def getSCT_FillCablingFromCoraCool(name="SCT_FillCablingFromCoraCool", **kwargs):
     from SCT_Cabling.SCT_CablingConf import SCT_FillCablingFromCoraCool
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfigDb.py b/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfigDb.py
index 0284d624ca803473559aee81a6ac064aaf3a890c..af8aaf583f966178f161ffb915063f70458bceb5 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfigDb.py
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/python/SCT_CablingConfigDb.py
@@ -6,5 +6,5 @@ from AthenaCommon.CfgGetter import addTool, addAlgorithm
 
 addTool("SCT_Cabling.SCT_CablingConfig.getSCT_CablingTool", "SCT_CablingTool")
 addAlgorithm("SCT_Cabling.SCT_CablingConfig.getSCT_CablingCondAlgFromCoraCool", "SCT_CablingCondAlgFromCoraCool")
-addTool("SCT_Cabling.SCT_CablingConfig.getSCT_CablingToolCB", "SCT_CablingToolCB")
+addTool("SCT_Cabling.SCT_CablingConfig.getSCT_CablingToolInc", "SCT_CablingToolInc")
 addTool("SCT_Cabling.SCT_CablingConfig.getSCT_FillCablingFromCoraCool", "SCT_FillCablingFromCoraCool")
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/src/components/SCT_Cabling_entries.cxx b/InnerDetector/InDetDetDescr/SCT_Cabling/src/components/SCT_Cabling_entries.cxx
index fb29b78888ee016f5fe80ce3f3d51ee2cf63c3d3..31ba57676fe76c290a180ba41a2328dbe606d8da 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/src/components/SCT_Cabling_entries.cxx
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/src/components/SCT_Cabling_entries.cxx
@@ -1,5 +1,5 @@
 #include "../SCT_CablingTool.h"
-#include "../SCT_CablingToolCB.h"
+#include "../SCT_CablingToolInc.h"
 #include "../SCT_FillCablingFromText.h"
 #include "../SCT_FillCablingFromCoraCool.h"
 #include "../SCT_TestCablingAlg.h"
@@ -7,7 +7,7 @@
 #include "../SCT_CablingCondAlgFromText.h"
 
 DECLARE_COMPONENT( SCT_CablingTool )
-DECLARE_COMPONENT( SCT_CablingToolCB )
+DECLARE_COMPONENT( SCT_CablingToolInc )
 DECLARE_COMPONENT( SCT_FillCablingFromText )
 DECLARE_COMPONENT( SCT_FillCablingFromCoraCool )
 DECLARE_COMPONENT( SCT_TestCablingAlg )
diff --git a/Trigger/TrigFTK/FastTrackSimWrap/FastTrackSimWrap/FTKRegionalWrapper.h b/Trigger/TrigFTK/FastTrackSimWrap/FastTrackSimWrap/FTKRegionalWrapper.h
index 9844bbb6ebabcd19a034b63a52192699f31b48cc..eb779d9ab0709808bbedfbd7062f70fc5e9ae6f4 100644
--- a/Trigger/TrigFTK/FastTrackSimWrap/FastTrackSimWrap/FTKRegionalWrapper.h
+++ b/Trigger/TrigFTK/FastTrackSimWrap/FastTrackSimWrap/FTKRegionalWrapper.h
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #ifndef FTKRegionalWrapper_h
@@ -58,7 +58,7 @@ private:
   ToolHandle<ITrigFTKClusterConverterTool>  m_clusterConverterTool; /** Tool to convert FTKHits to IDClusters */
 
   ServiceHandle<IPixelCablingSvc> m_pix_cabling_svc; 
-  ToolHandle<ISCT_CablingTool> m_sct_cablingToolCB; // This class accesses SCT cabling during initialization.
+  ToolHandle<ISCT_CablingTool> m_sct_cablingToolInc; // This class accesses SCT cabling during initialization.
 
   // Needed to retrieve m_pixelId in order to get the barrel_ec, phi/eta_modules etc.
 
diff --git a/Trigger/TrigFTK/FastTrackSimWrap/src/FTKRegionalWrapper.cxx b/Trigger/TrigFTK/FastTrackSimWrap/src/FTKRegionalWrapper.cxx
index 48775b6dfa7b54cb1711cf8c366d33da50970c52..827ef98bec19cfc779bb3c0f3a20a2e703208676 100644
--- a/Trigger/TrigFTK/FastTrackSimWrap/src/FTKRegionalWrapper.cxx
+++ b/Trigger/TrigFTK/FastTrackSimWrap/src/FTKRegionalWrapper.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 #include "xAODTracking/TrackParticleContainer.h"
 #include "FastTrackSimWrap/FTKRegionalWrapper.h"
@@ -46,7 +46,7 @@ FTKRegionalWrapper::FTKRegionalWrapper (const std::string& name, ISvcLocator* pS
   m_hitInputTool("FTK_SGHitInput/FTK_SGHitInput"),
   m_clusterConverterTool("TrigFTKClusterConverterTool"),
   m_pix_cabling_svc("PixelCablingSvc", name),
-  m_sct_cablingToolCB("SCT_CablingToolCB"),
+  m_sct_cablingToolInc("SCT_CablingToolInc"),
   m_storeGate(0),
   m_detStore( 0 ),
   m_evtStore(0 ),
@@ -146,7 +146,7 @@ FTKRegionalWrapper::FTKRegionalWrapper (const std::string& name, ISvcLocator* pS
   declareProperty("FixEndcapL0", m_fixEndcapL0);
   declareProperty("ITkMode",m_ITkMode);
   declareProperty("PixelCablingSvc", m_pix_cabling_svc);
-  declareProperty("SCT_CablingTool",m_sct_cablingToolCB);
+  declareProperty("SCT_CablingTool",m_sct_cablingToolInc);
 
   // hit type options
   declareProperty("SaveRawHits",m_SaveRawHits);
@@ -261,11 +261,11 @@ StatusCode FTKRegionalWrapper::initialize()
       log << MSG::FATAL << "SCT_Cabling not initialized so m_DumpTestVectors and m_EmulateDF must both be set to false!" << endmsg;
       return StatusCode::FAILURE;
     }
-  } else if (m_sct_cablingToolCB.retrieve().isFailure()) {
-    log << MSG::FATAL << "Failed to retrieve tool " << m_sct_cablingToolCB << endmsg;
+  } else if (m_sct_cablingToolInc.retrieve().isFailure()) {
+    log << MSG::FATAL << "Failed to retrieve tool " << m_sct_cablingToolInc << endmsg;
     return StatusCode::FAILURE;
   } else {
-    log << MSG::INFO << "Retrieved tool " << m_sct_cablingToolCB << endmsg;
+    log << MSG::INFO << "Retrieved tool " << m_sct_cablingToolInc << endmsg;
   }
 
   if (!m_SaveRawHits && !m_SaveHits) {
@@ -390,14 +390,14 @@ StatusCode FTKRegionalWrapper::initialize()
       //uint id = mit->first;
       ATH_MSG_DEBUG("Pixel offline map hashID to RobId "<<MSG::dec<<mit->first<<" "<<MSG::hex<<mit->second<<MSG::dec);
     }
-    ATH_MSG_DEBUG("Printing full SCT map  via m_sct_cablingToolCB->getAllRods()");
+    ATH_MSG_DEBUG("Printing full SCT map  via m_sct_cablingToolInc->getAllRods()");
     std::vector<uint32_t>  sctVector;
-    m_sct_cablingToolCB->getAllRods(sctVector);
-    ATH_MSG_DEBUG("Printing full SCT map  via m_sct_cablingToolCB->getAllRods() "<<sctVector.size()<<" rods ");
+    m_sct_cablingToolInc->getAllRods(sctVector);
+    ATH_MSG_DEBUG("Printing full SCT map  via m_sct_cablingToolInc->getAllRods() "<<sctVector.size()<<" rods ");
     
     for(auto mit = sctVector.begin(); mit != sctVector.end(); mit++){
 	// Retrive hashlist
-	m_sct_cablingToolCB->getHashesForRod(m_identifierHashList,*mit );
+	m_sct_cablingToolInc->getHashesForRod(m_identifierHashList,*mit );
 	ATH_MSG_DEBUG("Retrieved  "<<m_identifierHashList.size()<<" hashes ");
 
 	for (auto mhit = m_identifierHashList.begin(); mhit != m_identifierHashList.end(); mhit++)
@@ -641,7 +641,7 @@ StatusCode FTKRegionalWrapper::execute()
      	//SCT
 	
 	//then get the corresponding RobId
-	uint32_t robid = m_sct_cablingToolCB->getRobIdFromHash(modHash);
+	uint32_t robid = m_sct_cablingToolInc->getRobIdFromHash(modHash);
 	
 	if (dumpedSCT == false){
 	  ATH_MSG_VERBOSE("Dumping SCT Rod List ");
@@ -1070,7 +1070,7 @@ bool FTKRegionalWrapper::dumpFTKTestVectors(FTKPlaneMap *pmap, FTKRegionMap *rma
 // The getAllRods returns all of the rods in the StoreGateSvc
     hitTyp = 0;
     vector<uint32_t> sctrods;
-    m_sct_cablingToolCB->getAllRods(sctrods);
+    m_sct_cablingToolInc->getAllRods(sctrods);
     id = 0;
 
     for (uint32_t rod : sctrods) {
@@ -1086,7 +1086,7 @@ bool FTKRegionalWrapper::dumpFTKTestVectors(FTKPlaneMap *pmap, FTKRegionMap *rma
       if (myfile.is_open() ) {
 
 	// Retrive hashlist
-	 m_sct_cablingToolCB->getHashesForRod(m_identifierHashList,rod );
+	 m_sct_cablingToolInc->getHashesForRod(m_identifierHashList,rod );
 
 	 // Some dumping variables
 	 vector<IdentifierHash>::const_iterator hashit = m_identifierHashList.begin();
@@ -1096,7 +1096,7 @@ bool FTKRegionalWrapper::dumpFTKTestVectors(FTKPlaneMap *pmap, FTKRegionMap *rma
 	 for (; hashit != hashit_e; ++hashit){  // TODO: Check for invalid onlineId && hashId numbers (?)
 
 	    // Retrieve OnlineId
-	      sct_onlineId = m_sct_cablingToolCB->getOnlineIdFromHash( *hashit );
+	      sct_onlineId = m_sct_cablingToolInc->getOnlineIdFromHash( *hashit );
 	      if (sct_onlineId.rod()  == rod){ // Check for correct rodId
 
 		myfile.setf(ios::right | ios::showbase);
diff --git a/DetectorDescription/RegionSelector/src/RegSelSvc.cxx b/DetectorDescription/RegionSelector/src/RegSelSvc.cxx
index 04de029fab07154a3ca96cbb309b7fed3690e107..fa8fdd5ad972af787ba24172a6648ddf1869d033 100755
--- a/DetectorDescription/RegionSelector/src/RegSelSvc.cxx
+++ b/DetectorDescription/RegionSelector/src/RegSelSvc.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 
@@ -65,7 +65,7 @@ RegSelSvc::RegSelSvc(const std::string& name, ISvcLocator* sl)
     m_lutCreatorToolTRT  ("TRT_RegionSelectorTable/TRT_RegionSelectorTable"),
     m_lutCreatorToolLAR  ("LArRegionSelectorTable"),
     m_lutCreatorToolTile ("TileRegionSelectorTable"),
-    m_SCTCablingToolCB("SCT_CablingToolCB"),
+    m_SCTCablingToolInc("SCT_CablingToolInc"),
     m_geoModelSvc("GeoModelSvc",name),
     m_DeltaZ(168),
     m_initRPC(true),
@@ -180,8 +180,8 @@ StatusCode RegSelSvc::initialize() {
 
   if ( m_initOnlyID.value() ) { 
     if ( !m_initSCT.value() )   sctflag   = "disabled"; 
-    else ATH_CHECK(m_SCTCablingToolCB.retrieve()); // SCT_CablingToolCB has to be retrieved now.
-    // Otherwise, SCT_RegionSelectorTable cannot use ready SCT_CablingToolCB.
+    else ATH_CHECK(m_SCTCablingToolInc.retrieve()); // SCT_CablingToolInc has to be retrieved now.
+    // Otherwise, SCT_RegionSelectorTable cannot use ready SCT_CablingToolInc.
 
     if ( !m_initPixel.value() ) pixelflag = "disabled"; 
     if ( !m_initTRT.value() )   trtflag   = "disabled"; 
diff --git a/DetectorDescription/RegionSelector/src/RegSelSvc.h b/DetectorDescription/RegionSelector/src/RegSelSvc.h
index e021d5d7301775b88a68b7564ae8d667be3de341..6549ce60f43c9fb2a2649e06e47baefa1473d849 100755
--- a/DetectorDescription/RegionSelector/src/RegSelSvc.h
+++ b/DetectorDescription/RegionSelector/src/RegSelSvc.h
@@ -1,7 +1,7 @@
 // emacs: this is -*- c++ -*-
 
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 
@@ -454,7 +454,7 @@ private:
   ToolHandle<IRegionIDLUT_Creator> m_lutCreatorToolTRT;
   ToolHandle<IRegionLUT_Creator> m_lutCreatorToolLAR;
   ToolHandle<IRegionLUT_Creator> m_lutCreatorToolTile;
-  ToolHandle< ISCT_CablingTool > m_SCTCablingToolCB; // Retrieve SCT_CablingToolCB in initialize of RegSelSvc so that SCT_RegionSelectorTable can use ready SCT_CablingToolCB in BeginRun incident.
+  ToolHandle< ISCT_CablingTool > m_SCTCablingToolInc; // Retrieve SCT_CablingToolInc in initialize of RegSelSvc so that SCT_RegionSelectorTable can use ready SCT_CablingToolInc in BeginRun incident.
   ServiceHandle< IGeoModelSvc > m_geoModelSvc;
   std::vector<std::string> m_enabledDetectors;
   bool m_errorFlag;
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolCB.cxx b/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolInc.cxx
similarity index 69%
rename from InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolCB.cxx
rename to InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolInc.cxx
index c99cb35312fde597a15e3a2f93769a0776277827..d30f9265cde270e993bc7ae18e3b2e61d865d903 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolCB.cxx
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolInc.cxx
@@ -3,14 +3,14 @@
 */
 
 /**
  * @file SCT_CablingToolCB.cxx
  * Implementation file for SCT cabling tool using call back
  * @author Shaun Roe
  * @date 20 October, 2008
  **/
  
 //this package
-#include "SCT_CablingToolCB.h"
+#include "SCT_CablingToolInc.h"
 #include "SCT_Cabling/ISCT_FillCabling.h"
 #include "SCT_CablingUtilities.h"
 
@@ -41,14 +41,14 @@ namespace {
 }
 
 // Constructor
-SCT_CablingToolCB::SCT_CablingToolCB(const std::string& type, const std::string& name, const IInterface* parent) :
+SCT_CablingToolInc::SCT_CablingToolInc(const std::string& type, const std::string& name, const IInterface* parent) :
   base_class(type, name, parent), m_idHelper(nullptr), m_usingDatabase(true) {
   declareProperty("DataSource", m_cablingDataSource=defaultSource);
 }
 
 //
 void
-SCT_CablingToolCB::handle(const Incident& runIncident) {
+SCT_CablingToolInc::handle(const Incident& runIncident) {
   ATH_MSG_INFO("Cabling event handler called.");
   if (runIncident.type()==IncidentType::BeginRun) {
     if (not empty()) {
@@ -68,7 +68,7 @@ SCT_CablingToolCB::handle(const Incident& runIncident) {
 
 //
 StatusCode
-SCT_CablingToolCB::initialize() {
+SCT_CablingToolInc::initialize() {
   ATH_MSG_INFO("Initialize SCT cabling " << PACKAGE_VERSION);
   const std::string cablingDataSource = m_cablingDataSource.value();
   m_usingDatabase=(cablingDataSource == coracool) or (cablingDataSource == coolVectorPayload) or (cablingDataSource == file);
@@ -106,37 +106,37 @@ SCT_CablingToolCB::initialize() {
 
 // 
 StatusCode
-SCT_CablingToolCB::finalize() {
-  ATH_MSG_INFO("Thank-you for using the SCT_CablingToolCB, version "<<PACKAGE_VERSION);
+SCT_CablingToolInc::finalize() {
+  ATH_MSG_INFO("Thank-you for using the SCT_CablingToolInc, version "<<PACKAGE_VERSION);
   ATH_MSG_INFO("The cabling data source was "<< ((not m_usingDatabase) ? m_cablingFillerText->getDataSource() : m_cablingFillerCoraCool->getDataSource()));
   return StatusCode::SUCCESS;
 }
 
 //
 unsigned int
-SCT_CablingToolCB::size() const {
+SCT_CablingToolInc::size() const {
   return m_data.getHashEntries();
 }
 
 unsigned int
-SCT_CablingToolCB::size(const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::size(const EventContext& /*ctx*/) const {
   return size();
 }
 
 //
 bool
-SCT_CablingToolCB::empty() const {
+SCT_CablingToolInc::empty() const {
   return (size()==0);
 }
 
 bool
-SCT_CablingToolCB::empty(const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::empty(const EventContext& /*ctx*/) const {
   return empty();
 }
 
 //
 IdentifierHash 
-SCT_CablingToolCB::getHashFromOnlineId(const SCT_OnlineId& onlineId, const bool withWarnings) const {
+SCT_CablingToolInc::getHashFromOnlineId(const SCT_OnlineId& onlineId, const bool withWarnings) const {
   //is it valid at all?
   if (not onlineId.is_valid()) {
     if (withWarnings) ATH_MSG_WARNING("Invalid online id ("<<std::hex<<onlineId<<") "<<std::dec);
@@ -153,70 +153,70 @@ SCT_CablingToolCB::getHashFromOnlineId(const SCT_OnlineId& onlineId, const bool
 }
 
 IdentifierHash 
-SCT_CablingToolCB::getHashFromOnlineId(const SCT_OnlineId& onlineId, const EventContext& /*ctx*/, const bool withWarnings) const {
+SCT_CablingToolInc::getHashFromOnlineId(const SCT_OnlineId& onlineId, const EventContext& /*ctx*/, const bool withWarnings) const {
   return getHashFromOnlineId(onlineId, withWarnings);
 }
 
 //
 SCT_OnlineId 
-SCT_CablingToolCB::getOnlineIdFromHash(const IdentifierHash& hash) const {
+SCT_CablingToolInc::getOnlineIdFromHash(const IdentifierHash& hash) const {
   return m_data.getOnlineIdFromHash(hash);
 }
 
 SCT_OnlineId 
-SCT_CablingToolCB::getOnlineIdFromHash(const IdentifierHash& hash, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getOnlineIdFromHash(const IdentifierHash& hash, const EventContext& /*ctx*/) const {
   return getOnlineIdFromHash(hash);
 }
 
 //
 SCT_OnlineId
-SCT_CablingToolCB::getOnlineIdFromOfflineId(const Identifier& offlineId) const {
+SCT_CablingToolInc::getOnlineIdFromOfflineId(const Identifier& offlineId) const {
   if (not offlineId.is_valid()) return invalidId;
   IdentifierHash hash(m_idHelper->wafer_hash(offlineId));
   return getOnlineIdFromHash(hash);
 }
 
 SCT_OnlineId
-SCT_CablingToolCB::getOnlineIdFromOfflineId(const Identifier& offlineId, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getOnlineIdFromOfflineId(const Identifier& offlineId, const EventContext& /*ctx*/) const {
   return getOnlineIdFromOfflineId(offlineId);
 }
 
 //
 std::uint32_t
-SCT_CablingToolCB::getRobIdFromHash(const IdentifierHash& hash) const {
+SCT_CablingToolInc::getRobIdFromHash(const IdentifierHash& hash) const {
   return getOnlineIdFromHash(hash).rod();
 }
 
 std::uint32_t
-SCT_CablingToolCB::getRobIdFromHash(const IdentifierHash& hash, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getRobIdFromHash(const IdentifierHash& hash, const EventContext& /*ctx*/) const {
   return getRobIdFromHash(hash);
 }
 
 //
 std::uint32_t
-SCT_CablingToolCB::getRobIdFromOfflineId(const Identifier& offlineId) const {
+SCT_CablingToolInc::getRobIdFromOfflineId(const Identifier& offlineId) const {
   return getOnlineIdFromOfflineId(offlineId).rod();
 }
 
 std::uint32_t
-SCT_CablingToolCB::getRobIdFromOfflineId(const Identifier& offlineId, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getRobIdFromOfflineId(const Identifier& offlineId, const EventContext& /*ctx*/) const {
   return getRobIdFromOfflineId(offlineId);
 }
 
 //
 IdentifierHash
-SCT_CablingToolCB::getHashFromSerialNumber(const SCT_SerialNumber& sn) const {
+SCT_CablingToolInc::getHashFromSerialNumber(const SCT_SerialNumber& sn) const {
   if (not sn.isWellFormed()) return invalidHash;
   return m_data.getHashFromSerialNumber(sn);
 }
 
 IdentifierHash
-SCT_CablingToolCB::getHashFromSerialNumber(const SCT_SerialNumber& sn, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getHashFromSerialNumber(const SCT_SerialNumber& sn, const EventContext& /*ctx*/) const {
   return getHashFromSerialNumber(sn);
 }
 
 SCT_SerialNumber
-SCT_CablingToolCB::getSerialNumberFromHash(const IdentifierHash& hash) const {
+SCT_CablingToolInc::getSerialNumberFromHash(const IdentifierHash& hash) const {
   if (not hash.is_valid()) return invalidSn;
   //hash must be even
   IdentifierHash evenHash{even(hash)};
@@ -224,22 +224,22 @@ SCT_CablingToolCB::getSerialNumberFromHash(const IdentifierHash& hash) const {
 }
 
 SCT_SerialNumber
-SCT_CablingToolCB::getSerialNumberFromHash(const IdentifierHash& hash, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getSerialNumberFromHash(const IdentifierHash& hash, const EventContext& /*ctx*/) const {
   return getSerialNumberFromHash(hash);
 }
 
 void
-SCT_CablingToolCB::getAllRods(std::vector<std::uint32_t>& usersVector) const {
+SCT_CablingToolInc::getAllRods(std::vector<std::uint32_t>& usersVector) const {
   m_data.getRods(usersVector);
 }
 
 void
-SCT_CablingToolCB::getAllRods(std::vector<std::uint32_t>& usersVector, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getAllRods(std::vector<std::uint32_t>& usersVector, const EventContext& /*ctx*/) const {
   getAllRods(usersVector);
 }
 
 void
-SCT_CablingToolCB::getHashesForRod(std::vector<IdentifierHash>& usersVector, const std::uint32_t rodId) const {
+SCT_CablingToolInc::getHashesForRod(std::vector<IdentifierHash>& usersVector, const std::uint32_t rodId) const {
   SCT_OnlineId firstPossibleId(rodId,SCT_OnlineId::FIRST_FIBRE);
   const bool withWarnings(false);
   for (SCT_OnlineId i(firstPossibleId);i!=SCT_OnlineId::INVALID_ONLINE_ID;++i) {
@@ -251,6 +251,6 @@ SCT_CablingToolCB::getHashesForRod(std::vector<IdentifierHash>& usersVector, con
 }
 
 void
-SCT_CablingToolCB::getHashesForRod(std::vector<IdentifierHash>& usersVector, const std::uint32_t rodId, const EventContext& /*ctx*/) const {
+SCT_CablingToolInc::getHashesForRod(std::vector<IdentifierHash>& usersVector, const std::uint32_t rodId, const EventContext& /*ctx*/) const {
   getHashesForRod(usersVector, rodId);
 }
@@ -3,14 +3,14 @@
 
 /**
- * @file SCT_CablingToolCB.cxx
- * Implementation file for SCT cabling tool using call back
+ * @file SCT_CablingToolInc.cxx
+ * Implementation file for SCT cabling tool using incident
  * @author Shaun Roe
  * @date 20 October, 2008
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolCB.h b/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolInc.h
similarity index 87%
rename from InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolCB.h
rename to InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolInc.h
index 73cf362bbc56eabcd8ba7038f15e6069215ace76..21b1e2bd3a8c3d9264e209aac26bfa44b4f58af3 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolCB.h
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/src/SCT_CablingToolInc.h
@@ -2,11 +2,11 @@
   Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
-#ifndef SCT_CablingToolCB_h
-#define SCT_CablingToolCB_h
+#ifndef SCT_CablingToolInc_h
+#define SCT_CablingToolInc_h
 /**
  * @file SCT_CablingToolCB.h
  * Header file for  SCT cabling tool using call back
  * @author Shaun Roe
  * @date 20 October, 2008
  **/
@@ -35,9 +35,9 @@ class SCT_ID;
 class Identifier;
 
 /**
  * @class SCT_CablingToolCB, providing mappings of online and offline identifiers and also serial numbers
  **/
-class SCT_CablingToolCB: public extends<AthAlgTool, ISCT_CablingTool, IIncidentListener> {
+class SCT_CablingToolInc: public extends<AthAlgTool, ISCT_CablingTool, IIncidentListener> {
  public:
 
   ///Incident listener method
@@ -45,13 +45,13 @@ class SCT_CablingToolCB: public extends<AthAlgTool, ISCT_CablingTool, IIncidentL
     
   //@name Service methods, reimplemented
   //@{
-  SCT_CablingToolCB(const std::string& type, const std::string& name, const IInterface* parent);
-  virtual ~SCT_CablingToolCB() = default;
+  SCT_CablingToolInc(const std::string& type, const std::string& name, const IInterface* parent);
+  virtual ~SCT_CablingToolInc() = default;
   virtual StatusCode initialize() override;
   virtual StatusCode finalize() override;
   //@}
   
-  //@name ISCT_CablingToolCB methods implemented, these are visible to clients
+  //@name ISCT_CablingTool methods implemented, these are visible to clients
   //@{
   /// size of the data structure (for the SCT should be 8176, one for each module side)
   virtual unsigned int size(const EventContext& ctx) const override;
@@ -108,4 +108,4 @@ class SCT_CablingToolCB: public extends<AthAlgTool, ISCT_CablingTool, IIncidentL
   bool m_usingDatabase;
 };
 
-#endif // SCT_CablingToolCB_h
+#endif // SCT_CablingToolInc_h
@@ -2,11 +2,11 @@
 /**
- * @file SCT_CablingToolCB.h
- * Header file for  SCT cabling tool using call back
+ * @file SCT_CablingToolInc.h
+ * Header file for  SCT cabling tool using incident
  * @author Shaun Roe
  * @date 20 October, 2008
@@ -35,9 +35,9 @@ class SCT_ID;
 
 /**
- * @class SCT_CablingToolCB, providing mappings of online and offline identifiers and also serial numbers
+ * @class SCT_CablingToolInc, providing mappings of online and offline identifiers and also serial numbers
  **/